@@ -3,6 +3,7 @@ import time
 from pathlib import Path
 from importlib.metadata import version, PackageNotFoundError
 from typing import List, Dict, Any
+import asyncio
 
 try:
     __version__ = version("pixell-kit")
@@ -142,6 +143,27 @@ def mount(app: FastAPI) -> None:
         + "\n"
     )
 
+    # .env.example
+    (project_dir / ".env.example").write_text(
+        """# Environment Variables Template
+# Copy this file to `.env` and set values.
+
+# SECURITY: The `.env` file is included in your APKG package.
+# Use safe defaults or placeholders if you do not want to embed real secrets.
+
+# Example: OpenAI API Key
+# OPENAI_API_KEY=your-api-key-here
+
+# Example: Network bindings (use 0.0.0.0 in containers)
+# API_HOST=0.0.0.0
+# API_PORT=8080
+
+# Example: Database connection (prefer service names in Docker)
+# DB_HOST=database
+# DB_PORT=5432
+"""
+    )
+
     # README
     (project_dir / "README.md").write_text(
         f"""# {agent_yaml["display_name"]}
@@ -219,6 +241,77 @@ def dev(path, port):
     return run_dev.callback(path, port)  # type: ignore[attr-defined]
 
 
+@cli.command()
+@click.option("--path", "path_", default=".", help="Path to agent project")
+@click.option(
+    "--level",
+    "level",
+    type=click.Choice(["static", "build", "install", "runtime", "integration"]),
+    default="integration",
+    help="Test level to run",
+)
+@click.option(
+    "--category",
+    "category",
+    type=click.Choice(["security", "grpc", "rest", "env", "all"]),
+    default="all",
+    help="Test category to run",
+)
+@click.option("--json", "json_output", is_flag=True, help="Output JSON for CI/CD")
+@click.option("--verbose", "verbose", is_flag=True, help="Verbose output")
+def test(path_: str, level: str, category: str, json_output: bool, verbose: bool):
+    """Test agent comprehensively before deployment."""
+
+    import sys
+    from pixell.test.test_runner import AgentTester, TestLevel
+
+    project_dir = Path(path_)
+
+    if not json_output:
+        click.secho(f"\n🧪 Testing agent at: {project_dir}", fg="cyan", bold=True)
+        click.secho("=" * 60, fg="cyan")
+
+    # Currently category filtering is not implemented in runner; accept for future use
+    _ = category  # placeholder to avoid linter warnings
+
+    tester = AgentTester(project_dir, TestLevel(level), silent=json_output)
+    result = asyncio.run(tester.run_all_tests())
+
+    if json_output:
+        import json as json_lib
+
+        output = {
+            "success": result.success,
+            "passed": result.passed,
+            "failed": result.failed,
+            "warnings": result.warnings,
+            "skipped": result.skipped,
+        }
+        click.echo(json_lib.dumps(output, indent=2))
+    else:
+        click.echo("\n")
+        click.secho("=" * 60, fg="cyan")
+        click.secho("📊 Test Results", fg="cyan", bold=True)
+        click.secho("=" * 60, fg="cyan")
+
+        for msg in result.passed:
+            click.secho(msg, fg="green")
+        for msg in result.warnings:
+            click.secho(msg, fg="yellow")
+        for msg in result.failed:
+            click.secho(msg, fg="red")
+        for msg in result.skipped:
+            click.secho(msg, fg="blue")
+
+        click.echo("\n")
+        if result.success:
+            click.secho("✅ All tests passed!", fg="green", bold=True)
+            sys.exit(0)
+        else:
+            click.secho("❌ Tests failed", fg="red", bold=True)
+            sys.exit(1)
+
+
 @cli.command()
 @click.argument("package")
 def inspect(package):
@@ -926,6 +1019,7 @@ To build an agent package (.apkg file), you need:
   |-- src/                # REQUIRED: Agent source code
   |   |-- __init__.py
   |   |-- main.py         # Your agent implementation
+  |-- .env                # REQUIRED: Environment variables (included in APKG)
   |-- requirements.txt    # Optional: Python dependencies
   |-- mcp.json           # Optional: MCP configuration
   |-- README.md          # Optional: Documentation
